@@ -1,12 +1,13 @@
-from inspect import signature, Signature
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+
 import math
-from typing import Optional, Union, Tuple, List, Callable, Dict, Any
+from inspect import Signature, signature
 
 import numpy as np
-import sklearn.gaussian_process.kernels as kernels
 import scipy.optimize
 import scipy.spatial.distance
 import scipy.special
+import sklearn.gaussian_process.kernels as kernels
 
 from smac.epm.gp_base_prior import Prior
 
@@ -14,10 +15,8 @@ __copyright__ = "Copyright 2021, AutoML.org Freiburg-Hannover"
 __license__ = "3-clause BSD"
 
 
-# This file contains almost no type annotations to simplify comparing it to the original scikit-learn version!
-
-
-def get_conditional_hyperparameters(X: np.ndarray, Y: Optional[np.ndarray]) -> np.ndarray:
+def get_conditional_hyperparameters(X: np.ndarray, Y: Optional[np.ndarray] = None) -> np.ndarray:
+    """Returns conditional hyperparameters."""
     # Taking care of conditional hyperparameters according to Levesque et al.
     X_cond = X <= -1
     if Y is not None:
@@ -29,12 +28,13 @@ def get_conditional_hyperparameters(X: np.ndarray, Y: Optional[np.ndarray]) -> n
 
 
 class MagicMixin:
-
-    # This is a mixin for a kernel to override functions of the kernel. Because it overrides functions of the kernel,
-    # it needs to be placed first in the inheritance hierarchy. For this reason it is not possible to subclass the
-    # Mixin from the kernel class because this will prevent it from being instantiatable. Therefore, mypy won't know
-    # about anything related to the superclass and I had to add a few type:ignore statements when accessing a member
-    # that is declared in the superclass such as self.has_conditions, self._call, super().get_params etc.
+    # This is a mixin for a kernel to override functions of the kernel.
+    # Because it overrides functions of the kernel, it needs to be placed first in the inheritance
+    # hierarchy. For this reason it is not possible to subclass the
+    # Mixin from the kernel class because this will prevent it from being instantiatable.
+    # Therefore, mypy won't know about anything related to the superclass and I had
+    # to add a few type:ignore statements when accessing a member that is declared in the
+    # superclass such as self.has_conditions, self._call, super().get_params etc.
 
     prior = None  # type: Optional[Prior]
 
@@ -45,7 +45,7 @@ class MagicMixin:
         eval_gradient: bool = False,
         active: Optional[np.ndarray] = None,
     ) -> Union[np.ndarray, Tuple[np.ndarray, np.ndarray]]:
-
+        """Call the kernel function."""
         if active is None and self.has_conditions:  # type: ignore[attr-defined] # noqa F821
             if self.operate_on is None:
                 active = get_conditional_hyperparameters(X, Y)
@@ -58,6 +58,9 @@ class MagicMixin:
         if self.operate_on is None:
             rval = self._call(X, Y, eval_gradient, active)  # type: ignore[attr-defined] # noqa F821
         else:
+            if self.len_active is None:
+                raise RuntimeError("len_active is not set.")
+
             if Y is None:
                 rval = self._call(  # type: ignore[attr-defined] # noqa F821
                     X=X[:, self.operate_on].reshape([-1, self.len_active]),
@@ -136,8 +139,8 @@ class MagicMixin:
             args = list(tmp.keys())
             # Sum and Product do not clone the 'has_conditions' attribute by default. Instead of changing their
             # get_params() method, we simply add the attribute here!
-            if 'has_conditions' not in args:
-                args.append('has_conditions')
+            if "has_conditions" not in args:
+                args.append("has_conditions")
             self._args_cache = args  # type: List[Union[str, Any]]
 
         for arg in args:
@@ -160,13 +163,12 @@ class MagicMixin:
     @property
     def n_dims(self) -> int:
         """Returns the number of non-fixed hyperparameters of the kernel."""
-
         try:
             return self._n_dims_cache
         except AttributeError:
             pass
 
-        self._n_dims_cache = -1  # type: int # I cannot use `varname: type = value` syntax because that's >=Python3.6
+        self._n_dims_cache = -1  # type: int
         self._n_dims_cache = super().n_dims  # type: ignore[misc] # noqa F821
         return self._n_dims_cache
 
@@ -182,7 +184,7 @@ class MagicMixin:
         return self
 
     def set_active_dims(self, operate_on: Optional[np.ndarray] = None) -> None:
-        """Sets dimensions this kernel should work on
+        """Sets dimensions this kernel should work on.
 
         Parameters
         ----------
@@ -190,9 +192,9 @@ class MagicMixin:
         """
         if operate_on is not None and type(operate_on) in (list, np.ndarray):
             if not isinstance(operate_on, np.ndarray):
-                raise TypeError('argument operate_on needs to be of type np.ndarray, but is %s' % type(operate_on))
-            if operate_on.dtype != np.int:
-                raise ValueError('dtype of argument operate_on needs to be np.int, but is %s' % operate_on.dtype)
+                raise TypeError("argument operate_on needs to be of type np.ndarray, but is %s" % type(operate_on))
+            if operate_on.dtype != int:
+                raise ValueError("dtype of argument operate_on needs to be int, but is %s" % operate_on.dtype)
             self.operate_on = operate_on  # type: Optional[np.ndarray]
             self.len_active = len(operate_on)  # type: Optional[int]
         else:
@@ -201,7 +203,6 @@ class MagicMixin:
 
 
 class Sum(MagicMixin, kernels.Sum):
-
     def __init__(
         self,
         k1: kernels.Kernel,
@@ -257,7 +258,6 @@ class Sum(MagicMixin, kernels.Sum):
 
 
 class Product(MagicMixin, kernels.Product):
-
     def __init__(
         self,
         k1: kernels.Kernel,
@@ -307,14 +307,12 @@ class Product(MagicMixin, kernels.Product):
         if eval_gradient:
             K1, K1_gradient = self.k1(X, Y, eval_gradient=True, active=active)
             K2, K2_gradient = self.k2(X, Y, eval_gradient=True, active=active)
-            return K1 * K2, np.dstack((K1_gradient * K2[:, :, np.newaxis],
-                                       K2_gradient * K1[:, :, np.newaxis]))
+            return K1 * K2, np.dstack((K1_gradient * K2[:, :, np.newaxis], K2_gradient * K1[:, :, np.newaxis]))
         else:
             return self.k1(X, Y, active=active) * self.k2(X, Y, active=active)
 
 
 class ConstantKernel(MagicMixin, kernels.ConstantKernel):
-
     def __init__(
         self,
         constant_value: float = 1.0,
@@ -370,13 +368,21 @@ class ConstantKernel(MagicMixin, kernels.ConstantKernel):
         elif eval_gradient:
             raise ValueError("Gradient can only be evaluated when Y is None.")
 
-        K = np.full((X.shape[0], Y.shape[0]), self.constant_value,
-                    dtype=np.array(self.constant_value).dtype)
+        K = np.full(
+            (X.shape[0], Y.shape[0]),
+            self.constant_value,
+            dtype=np.array(self.constant_value).dtype,
+        )
         if eval_gradient:
             if not self.hyperparameter_constant_value.fixed:
-                return (K, np.full((X.shape[0], X.shape[0], 1),
-                                   self.constant_value,
-                                   dtype=np.array(self.constant_value).dtype))
+                return (
+                    K,
+                    np.full(
+                        (X.shape[0], X.shape[0], 1),
+                        self.constant_value,
+                        dtype=np.array(self.constant_value).dtype,
+                    ),
+                )
             else:
                 return K, np.empty((X.shape[0], X.shape[0], 0))
         else:
@@ -384,11 +390,13 @@ class ConstantKernel(MagicMixin, kernels.ConstantKernel):
 
 
 class Matern(MagicMixin, kernels.Matern):
-
     def __init__(
         self,
-        length_scale: Union[float, Tuple[float, ...]] = 1.0,
-        length_scale_bounds: Union[Tuple[float, float], List[Tuple[float, float]]] = (1e-5, 1e5),
+        length_scale: Union[float, Tuple[float, ...], np.ndarray] = 1.0,
+        length_scale_bounds: Union[Tuple[float, float], List[Tuple[float, float]], np.ndarray] = (
+            1e-5,
+            1e5,
+        ),
         nu: float = 1.5,
         operate_on: Optional[np.ndarray] = None,
         prior: Optional[Prior] = None,
@@ -407,7 +415,7 @@ class Matern(MagicMixin, kernels.Matern):
         eval_gradient: bool = False,
         active: Optional[np.ndarray] = None,
     ) -> Union[np.ndarray, Tuple[np.ndarray, np.ndarray]]:
-        """ Return the kernel k(X, Y) and optionally its gradient.
+        """Return the kernel k(X, Y) and optionally its gradient.
 
         Parameters
         ----------
@@ -431,32 +439,30 @@ class Matern(MagicMixin, kernels.Matern):
             hyperparameter of the kernel. Only returned when eval_gradient
             is True.
         """
-
         X = np.atleast_2d(X)
         length_scale = kernels._check_length_scale(X, self.length_scale)
 
         if Y is None:
-            dists = scipy.spatial.distance.pdist(X / length_scale, metric='euclidean')
+            dists = scipy.spatial.distance.pdist(X / length_scale, metric="euclidean")
         else:
             if eval_gradient:
-                raise ValueError(
-                    "Gradient can only be evaluated when Y is None.")
-            dists = scipy.spatial.distance.cdist(X / length_scale, Y / length_scale, metric='euclidean')
+                raise ValueError("Gradient can only be evaluated when Y is None.")
+            dists = scipy.spatial.distance.cdist(X / length_scale, Y / length_scale, metric="euclidean")
 
         if self.nu == 0.5:
             K = np.exp(-dists)
         elif self.nu == 1.5:
             K = dists * math.sqrt(3)
-            K = (1. + K) * np.exp(-K)
+            K = (1.0 + K) * np.exp(-K)
         elif self.nu == 2.5:
             K = dists * math.sqrt(5)
-            K = (1. + K + K ** 2 / 3.0) * np.exp(-K)
+            K = (1.0 + K + K**2 / 3.0) * np.exp(-K)
         else:  # general case; expensive to evaluate
             K = dists
             K[K == 0.0] += np.finfo(float).eps  # strict zeros result in nan
-            tmp = (math.sqrt(2 * self.nu) * K)
-            K.fill((2 ** (1. - self.nu)) / scipy.special.gamma(self.nu))
-            K *= tmp ** self.nu
+            tmp = math.sqrt(2 * self.nu) * K
+            K.fill((2 ** (1.0 - self.nu)) / scipy.special.gamma(self.nu))
+            K *= tmp**self.nu
             K *= scipy.special.kv(self.nu, tmp)
 
         if Y is None:
@@ -475,9 +481,9 @@ class Matern(MagicMixin, kernels.Matern):
 
             # We need to recompute the pairwise dimension-wise distances
             if self.anisotropic:
-                D = (X[:, np.newaxis, :] - X[np.newaxis, :, :]) ** 2 / (length_scale ** 2)
+                D = (X[:, np.newaxis, :] - X[np.newaxis, :, :]) ** 2 / (length_scale**2)
             else:
-                D = scipy.spatial.distance.squareform(dists ** 2)[:, :, np.newaxis]
+                D = scipy.spatial.distance.squareform(dists**2)[:, :, np.newaxis]
 
             if self.nu == 0.5:
                 K_gradient = K[..., np.newaxis] * D / np.sqrt(D.sum(2))[:, :, np.newaxis]
@@ -501,11 +507,13 @@ class Matern(MagicMixin, kernels.Matern):
 
 
 class RBF(MagicMixin, kernels.RBF):
-
     def __init__(
         self,
         length_scale: Union[float, Tuple[float, ...]] = 1.0,
-        length_scale_bounds: Union[Tuple[float, float], List[Tuple[float, float]]] = (1e-5, 1e5),
+        length_scale_bounds: Union[Tuple[float, float], List[Tuple[float, float]]] = (
+            1e-5,
+            1e5,
+        ),
         operate_on: Optional[np.ndarray] = None,
         prior: Optional[Prior] = None,
         has_conditions: bool = False,
@@ -547,22 +555,20 @@ class RBF(MagicMixin, kernels.RBF):
             hyperparameter of the kernel. Only returned when eval_gradient
             is True.
         """
-
         X = np.atleast_2d(X)
         length_scale = kernels._check_length_scale(X, self.length_scale)
 
         if Y is None:
-            dists = scipy.spatial.distance.pdist(X / length_scale, metric='sqeuclidean')
-            K = np.exp(-.5 * dists)
+            dists = scipy.spatial.distance.pdist(X / length_scale, metric="sqeuclidean")
+            K = np.exp(-0.5 * dists)
             # convert from upper-triangular matrix to square matrix
             K = scipy.spatial.distance.squareform(K)
             np.fill_diagonal(K, 1)
         else:
             if eval_gradient:
-                raise ValueError(
-                    "Gradient can only be evaluated when Y is None.")
-            dists = scipy.spatial.distance.cdist(X / length_scale, Y / length_scale, metric='sqeuclidean')
-            K = np.exp(-.5 * dists)
+                raise ValueError("Gradient can only be evaluated when Y is None.")
+            dists = scipy.spatial.distance.cdist(X / length_scale, Y / length_scale, metric="sqeuclidean")
+            K = np.exp(-0.5 * dists)
 
         if active is not None:
             K = K * active
@@ -576,7 +582,7 @@ class RBF(MagicMixin, kernels.RBF):
                 return K, K_gradient
             elif self.anisotropic:
                 # We need to recompute the pairwise dimension-wise distances
-                K_gradient = (X[:, np.newaxis, :] - X[np.newaxis, :, :]) ** 2 / (length_scale ** 2)
+                K_gradient = (X[:, np.newaxis, :] - X[np.newaxis, :, :]) ** 2 / (length_scale**2)
                 K_gradient *= K[..., np.newaxis]
                 return K, K_gradient
 
@@ -584,11 +590,13 @@ class RBF(MagicMixin, kernels.RBF):
 
 
 class WhiteKernel(MagicMixin, kernels.WhiteKernel):
-
     def __init__(
         self,
         noise_level: Union[float, Tuple[float, ...]] = 1.0,
-        noise_level_bounds: Union[Tuple[float, float], List[Tuple[float, float]]] = (1e-5, 1e5),
+        noise_level_bounds: Union[Tuple[float, float], List[Tuple[float, float]]] = (
+            1e-5,
+            1e5,
+        ),
         operate_on: Optional[np.ndarray] = None,
         prior: Optional[Prior] = None,
         has_conditions: bool = False,
@@ -606,7 +614,7 @@ class WhiteKernel(MagicMixin, kernels.WhiteKernel):
         eval_gradient: bool = False,
         active: Optional[np.ndarray] = None,
     ) -> Union[np.ndarray, Tuple[np.ndarray, np.ndarray]]:
-        """ Return the kernel k(X, Y) and optionally its gradient.
+        """Return the kernel k(X, Y) and optionally its gradient.
 
         Parameters
         ----------
@@ -630,7 +638,6 @@ class WhiteKernel(MagicMixin, kernels.WhiteKernel):
             hyperparameter of the kernel. Only returned when eval_gradient
             is True.
         """
-
         X = np.atleast_2d(X)
 
         if Y is not None and eval_gradient:
@@ -653,12 +660,19 @@ class WhiteKernel(MagicMixin, kernels.WhiteKernel):
             return np.zeros((X.shape[0], Y.shape[0]))
 
 
-class HammingKernel(MagicMixin, kernels.StationaryKernelMixin, kernels.NormalizedKernelMixin, kernels.Kernel):
-
+class HammingKernel(
+    MagicMixin,
+    kernels.StationaryKernelMixin,
+    kernels.NormalizedKernelMixin,
+    kernels.Kernel,
+):
     def __init__(
         self,
-        length_scale: Union[float, Tuple[float, ...]] = 1.0,
-        length_scale_bounds: Union[Tuple[float, float], List[Tuple[float, float]]] = (1e-5, 1e5),
+        length_scale: Union[float, Tuple[float, ...], np.ndarray] = 1.0,
+        length_scale_bounds: Union[Tuple[float, float], List[Tuple[float, float]], np.ndarray] = (
+            1e-5,
+            1e5,
+        ),
         operate_on: Optional[np.ndarray] = None,
         prior: Optional[Prior] = None,
         has_conditions: bool = False,
@@ -671,6 +685,7 @@ class HammingKernel(MagicMixin, kernels.StationaryKernelMixin, kernels.Normalize
 
     @property
     def hyperparameter_length_scale(self) -> kernels.Hyperparameter:
+        """Hyperparameter of the length scale."""
         length_scale = self.length_scale
         anisotropic = np.iterable(length_scale) and len(length_scale) > 1  # type: ignore
         if anisotropic:
@@ -714,7 +729,6 @@ class HammingKernel(MagicMixin, kernels.StationaryKernelMixin, kernels.Normalize
         Code partially copied from skopt (https://github.com/scikit-optimize).
         Made small changes to only compute necessary values and use scikit-learn helper functions.
         """
-
         X = np.atleast_2d(X)
         length_scale = kernels._check_length_scale(X, self.length_scale)
 
@@ -738,12 +752,12 @@ class HammingKernel(MagicMixin, kernels.StationaryKernelMixin, kernels.Normalize
             # dK / d theta = l * dK / dl
 
             # dK / dL computation
-            if np.iterable(length_scale) and length_scale.shape[0] > 1:
-                grad = (np.expand_dims(K, axis=-1) * np.array(indicator, dtype=np.float32))
+            if np.iterable(length_scale) and length_scale.shape[0] > 1:  # type: ignore
+                grad = np.expand_dims(K, axis=-1) * np.array(indicator, dtype=np.float32)
             else:
                 grad = np.expand_dims(K * np.sum(indicator, axis=2), axis=-1)
 
-            grad *= (1 / length_scale ** 3)
+            grad *= 1 / length_scale**3
 
             return K, grad
         return K
