@@ -20,10 +20,9 @@ class RandomConfigurations(InitialDesign):
         config: Configuration()
             Initial incumbent configuration
         """
-
         configs = self.cs.sample_configuration(size=self.init_budget)
         if self.init_budget == 1:
             configs = [configs]
         for config in configs:
-            config.origin = 'Random initial design.'
+            config.origin = "Random initial design."
         return configs
